@@ -2,21 +2,16 @@
 """JSON callable module ~ jsonbourne"""
 import sys
 
-from jsonbourne import json
+from jsonbourne import __version__, json
 from jsonbourne._import import import_json
-from jsonbourne._version import (
-    VERSION_INFO,
-    VERSION_MAJOR,
-    VERSION_MINOR,
-    VERSION_PATCH,
-    __version__,
-)
 from jsonbourne.core import (
     JSON,
+    UNDEFINED,
     JsonDict,
     JSONModuleCls,
     JsonObj,
     JsonObjMutableMapping,
+    undefined,
 )
 
 
@@ -30,6 +25,7 @@ parse = JSON.parse
 json_lib = JSON.json_lib
 
 __all__ = [
+    "__version__",
     "json",  # json compat lib
     # core
     "JsonObjMutableMapping",
@@ -46,10 +42,6 @@ __all__ = [
     "loads",
     "json_lib",
     "parse",
-    # Version stuff
-    "VERSION_MAJOR",
-    "VERSION_MINOR",
-    "VERSION_PATCH",
-    "VERSION_INFO",
-    "__version__",
+    "undefined",
+    "UNDEFINED",
 ]
